@@ -26,7 +26,6 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s unshared folder \"%2$s\" with you",
     "Someone unshared folder \"%s\" with you" : "Someone unshared folder \"%s\" with you",
     "No file provided for import" : "هیچ پرونده ای برای واردکردن ارائه نشده است",
-    "Unsupported file type for import" : "این نوع فایل برای افزودن پشتیبانی نمی شود",
     "Bookmarks shared by %s" : "Bookmarks shared by %s",
     "Frequent bookmarks" : "Frequent bookmarks",
     "Recent bookmarks" : "Recent bookmarks",
@@ -63,8 +62,6 @@ OC.L10N.register(
     "Cancel selection" : "Cancel selection",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Selected {folders} folders and {bookmarks} bookmarks",
     "Do you really want to delete these items?" : "Do you really want to delete these items?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["انتخاب شده %n نشانک","انتخاب شده %n نشانک های"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Selected %n folder","Selected %n folders"],
     "Go back" : "برگرد",
     "Share folder" : "اشتراک‌گذاری پوشه",
     "Select one or more tags" : "یک یا چند تگ را انتخاب کنید",
@@ -84,13 +81,10 @@ OC.L10N.register(
     "Sort by manual order" : "Sort by manual order",
     "Sort by URL" : "Sort by URL",
     "RSS feed copied" : "RSS feed copied",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Adding %n bookmark to new folder","Adding %n bookmarks to new folder"],
     "Enter a link" : "پیوند را وارد کنید",
     "Enter a title" : "Enter a title",
     "No bookmarks found" : "No bookmarks found",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} folders and {bookmarks} bookmarks",
-    "_%n bookmark_::_%n bookmarks_" : ["%n نشانک","%n نشانک"],
-    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
     "Welcome to Bookmarks" : "Welcome to Bookmarks",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app.",
     "Add a bookmark" : "یک نشانک اضافه کنید",
@@ -109,9 +103,6 @@ OC.L10N.register(
     "Importing bookmarks" : "Importing bookmarks",
     "Moving selection" : "Moving selection",
     "Adding selection to folders" : "Adding selection to folders",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["در حال انتقال %nپوشه ها و برخی نشانک ها","در حال انتقال %n پوشه ها و برخی نشانک ها"],
-    "_Moving %n folder_::_Moving %n folders_" : ["در حال انتقال %n پوشه","در حال انتقال %n پوشه ها"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["در حال انتقال %n نشانک","در حال انتقال %n نشانک ها"],
     "All bookmarks" : "همه نشانک‌ها",
     "Recent" : "اخیر",
     "Shared with you" : "با شما به اشتراک گذاشته شده است",
@@ -123,7 +114,6 @@ OC.L10N.register(
     "Delete" : "حذف",
     "Untagged" : "غیرقابل تشخیص",
     "{used} bookmarks of {available} available" : "{used} bookmarks of {available} available",
-    "Settings" : "تنظیمات",
     "No bookmarked files" : "No bookmarked files",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline.",
     "No broken links" : "No broken links",
