@@ -5,19 +5,17 @@ OC.L10N.register(
     "Rename" : "Renominar",
     "Copy link" : "Copiar ligamine",
     "Move" : "Mover",
-    "Delete" : "Deler",
     "Select all" : "Selectionar toto",
     "Go back" : "Retornar",
     "New" : "Nove",
     "New folder" : "Nove dossier",
     "Search" : "Cercar",
     "Rename folder" : "Renominar dossier",
-    "Delete folder" : "Deler dossier",
     "Cancel" : "Cancellar",
     "Recent" : "Recente",
     "Shared with you" : "Compartite con te",
     "Files" : "Files",
-    "Settings" : "Configurationes",
+    "Delete" : "Deler",
     "Title" : "Titulo",
     "Link" : "Ligamine",
     "Tags" : "Etiquettas",
