@@ -85,12 +85,12 @@ class FoldersController extends ApiController {
 		if ($this->authorizer->getToken() !== null) {
 			try {
 				/**
-				 * @var $publicFolder PublicFolder
+				 * @var PublicFolder $publicFolder
 				 */
 				$publicFolder = $this->publicFolderMapper->find($this->authorizer->getToken());
 				$this->rootFolderId = $publicFolder->getFolderId();
-			} catch (DoesNotExistException | MultipleObjectsReturnedException $e) {
-				$this->logger->error($e->getMessage()."\n".$e->getMessage());
+			} catch (DoesNotExistException|MultipleObjectsReturnedException $e) {
+				$this->logger->error($e->getMessage() . "\n" . $e->getMessage());
 			}
 		}
 		return $this->rootFolderId;
@@ -765,7 +765,7 @@ class FoldersController extends ApiController {
 				$res->throttle();
 				return $res;
 			}
-			return new Http\DataResponse(['status' => 'success', 'data' => $share->toArray()]);
+			return new Http\DataResponse(['status' => 'success', 'data' => [$share->toArray()]]);
 		}
 		$res = new DataResponse(['status' => 'error', 'data' => ['Could not find folder']], Http::STATUS_NOT_FOUND);
 		$res->throttle();
@@ -869,7 +869,7 @@ class FoldersController extends ApiController {
 
 		try {
 			$this->folders->deleteShare($shareId);
-		} catch (UnsupportedOperation | DoesNotExistException | MultipleObjectsReturnedException | Exception $e) {
+		} catch (UnsupportedOperation|DoesNotExistException|MultipleObjectsReturnedException|Exception $e) {
 			return new Http\DataResponse(['status' => 'error', 'data' => ['Internal error']], Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 		return new Http\DataResponse(['status' => 'success']);
